.. py:module:: bcdi.graph

.. toctree::
   :maxdepth: 2

:mod:`bcdi.graph`: Templates for plotting and saving data
=========================================================

graph_utils
^^^^^^^^^^^

This module provides methods to plot 2D and 3D data using templates, and to save it
as a .vti file.

API Reference
-------------

.. automodule:: bcdi.graph.graph_utils
   :members:
